#define UTS_RELEASE "2.4.19-rmk6-pxa1-hh28"
#define LINUX_VERSION_CODE 132115
#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
